/*
 *  Copyright (C) 2007 Neil Jagdish Patel <njpatel@gmail.com>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA.
 *
 *  Author : Neil Jagdish Patel <njpatel@gmail.com>
*/

#ifndef _AWN_UTILS_
#define _AWN_UTILS_

#include <gtk/gtk.h>
#include <libawn/awn-settings.h>

typedef struct {
	/*
	GnomeDesktopItem *desktop_item
	
	*/
	gint place_holder;	
} AwnSmartLauncher;

void awn_hide (AwnSettings *settings);
void awn_show (AwnSettings *settings);

void hide_window (GtkWindow *window);
void show_window (GtkWindow *window);



#endif
